"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.molliePaymentHandler = void 0;
const core_1 = require("@vendure/core");
const generated_types_1 = require("@vendure/common/lib/generated-types");
const api_client_1 = __importDefault(require("@mollie/api-client"));
const mollie_plugin_1 = require("./mollie.plugin");
exports.molliePaymentHandler = new core_1.PaymentMethodHandler({
    code: "mollie-payment-handler",
    description: [
        {
            languageCode: generated_types_1.LanguageCode.en,
            value: "Mollie payment"
        }
    ],
    args: {
        apiKey: {
            type: "string"
        },
        redirectUrl: {
            type: "string"
        }
    },
    /** This is called when the `addPaymentToOrder` mutation is executed */
    createPayment: async (ctx, order, amount, args, metadata) => {
        try {
            let { apiKey, redirectUrl } = args;
            if (redirectUrl && !redirectUrl.endsWith("/")) {
                redirectUrl = `${redirectUrl}/`; // append slash if
            }
            const mollieClient = api_client_1.default({ apiKey });
            const payment = await mollieClient.payments.create({
                customerId: "",
                mandateId: "",
                amount: {
                    value: `${(order.totalWithTax / 100).toFixed(2)}`,
                    currency: "EUR"
                },
                metadata: {
                    orderCode: order.code
                },
                description: `Bestelling ${order.code}`,
                redirectUrl: `${redirectUrl}order/${order.code}`,
                webhookUrl: `${mollie_plugin_1.MolliePlugin.host}/payments/mollie/${ctx.channel.token}`
            });
            return {
                amount: order.totalWithTax,
                transactionId: payment.id,
                state: "Authorized",
                metadata: {
                    public: {
                        redirectLink: payment.getPaymentUrl()
                    }
                }
            };
        }
        catch (err) {
            core_1.Logger.error(err, mollie_plugin_1.MolliePlugin.context);
            return {
                amount: order.totalWithTax,
                state: "Declined",
                metadata: {
                    errorMessage: err.message
                }
            };
        }
    },
    /** This is called when the `settlePayment` mutation is executed */
    settlePayment: async (order, payment, args) => {
        return { success: true };
    }
});
